# Model Feature Scan Report
_Report generated on: 2025-06-12T07:37:10.315442_

## API: OpenAIApi

### API Summary
*   **Total Models Scanned:** 40
*   **Average Supported Features per Model:** 3.00

#### Feature Support Across Models:
*   Audio: 0.0% (0/40)
*   AudioConversion: 0.0% (0/40)
*   AudioEmbeddings: 7.5% (3/40)
*   AudioGeneration: 7.5% (3/40)
*   AudioTranscription: 5.0% (2/40)
*   Document: 0.0% (0/40)
*   DocumentConversion: 0.0% (0/40)
*   DocumentEmbeddings: 7.5% (3/40)
*   Image: 32.5% (13/40)
*   ImageConversion: 0.0% (0/40)
*   ImageEmbeddings: 7.5% (3/40)
*   ImageGeneration: 7.5% (3/40)
*   MCPTool: 47.5% (19/40)
*   StructuredTextGeneration: 37.5% (15/40)
*   TextEmbeddings: 7.5% (3/40)
*   TextGeneration: 47.5% (19/40)
*   Thinking: 22.5% (9/40)
*   Tools: 45.0% (18/40)
*   Video: 0.0% (0/40)
*   VideoConversion: 0.0% (0/40)
*   VideoEmbeddings: 7.5% (3/40)
*   VideoGeneration: 0.0% (0/40)
*   WebSearchTool: 10.0% (4/40)

### Model Details

#### Model: chatgpt-4o-latest (4/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: dall-e-2 (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ✅ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: dall-e-3 (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ✅ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: fastembed (5/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ✅ TextEmbeddings
*   ✅ ImageEmbeddings
*   ✅ AudioEmbeddings
*   ✅ VideoEmbeddings
*   ✅ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-3.5-turbo (3/23 features supported)
*   ✅ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-3.5-turbo-16k (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-3.5-turbo-instruct (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4 (3/23 features supported)
*   ✅ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4-turbo (4/23 features supported)
*   ✅ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4-turbo-preview (3/23 features supported)
*   ✅ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4.1 (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4.1-mini (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4.1-nano (5/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-audio-preview (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-mini (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ✅ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-mini-audio-preview (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-mini-realtime-preview (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-mini-search-preview (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-mini-transcribe (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-mini-tts (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ✅ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-realtime-preview (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-search-preview (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-4o-transcribe (0/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: gpt-image-1 (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ✅ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o1-high (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o1-low (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o1-medium (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o3-high (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o3-low (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o3-medium (6/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ✅ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o3-mini-high (5/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o3-mini-low (5/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: o3-mini-medium (5/23 features supported)
*   ✅ TextGeneration
*   ✅ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ✅ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ✅ Tools
*   ❌ WebSearchTool
*   ✅ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: text-embedding-3-large (5/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ✅ TextEmbeddings
*   ✅ ImageEmbeddings
*   ✅ AudioEmbeddings
*   ✅ VideoEmbeddings
*   ✅ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: text-embedding-3-small (5/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ✅ TextEmbeddings
*   ✅ ImageEmbeddings
*   ✅ AudioEmbeddings
*   ✅ VideoEmbeddings
*   ✅ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: tts-1 (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ✅ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: tts-1-hd (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ✅ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ❌ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: whisper-1 (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ✅ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

#### Model: whisper-local (1/23 features supported)
*   ❌ TextGeneration
*   ❌ StructuredTextGeneration
*   ❌ ImageGeneration
*   ❌ AudioGeneration
*   ❌ VideoGeneration
*   ❌ Thinking
*   ❌ TextEmbeddings
*   ❌ ImageEmbeddings
*   ❌ AudioEmbeddings
*   ❌ VideoEmbeddings
*   ❌ DocumentEmbeddings
*   ❌ Image
*   ❌ Audio
*   ❌ Video
*   ❌ Document
*   ❌ Tools
*   ❌ WebSearchTool
*   ❌ MCPTool
*   ✅ AudioTranscription
*   ❌ ImageConversion
*   ❌ AudioConversion
*   ❌ VideoConversion
*   ❌ DocumentConversion

_This report is auto-generated by Litemind. Some features may not be supported due to model limitations, API restrictions, or potential bugs in Litemind._